#!/bin/bash

set -e

cd /osgeo/download/osgeo4w

if ! lockfile -l 600 .lock/symstore.lock; then
	echo Locking symstore failed
	exit 1
fi

trap "rm -f $PWD/.lock/symstore.lock" EXIT

for i in qgis-rel-dev qgis-ltr-dev qgis qgis-ltr qgis-dev; do
	for a in x86 x86_64; do
		d=$a/symstores/$i
		mkdir -p $d

		for p in $(ls -1 $a/release/qgis/$i-pdb/$i-pdb-*.tar.bz2 | sort -V | tail -2); do
			[ -s $p ] || continue
			fgrep -qsx "$p" $d/files.lst && continue

			echo Updating symstore $a/$i

			v=${p%-*-*.tar.bz2}
			v=${p#$v-}
			v=${v%.tar.bz2}
	
			t=$(mktemp -d)
			if tar -C "$t" -xf $p; then
				symstore -z -p $i -r $v $a/symstores/$i $t/apps/$i/pdb/*.pdb
			else
				echo Extracting $p failed
			fi

			rm -r "$t"

			echo $p >>$d/files.lst
		done

		du -sch $d
		perl clean-symstore.pl $d
		du -sch $d
	done
done

